/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.datastax.driver.core;

/**
 * A timestamp generator that always returns {@link Long#MIN_VALUE}, in order to let Cassandra
 * assign server-side timestamps.
 */
public class ServerSideTimestampGenerator implements TimestampGenerator {
  /** The unique instance of this generator. */
  public static final TimestampGenerator INSTANCE = new ServerSideTimestampGenerator();

  @Override
  public long next() {
    return Long.MIN_VALUE;
  }

  private ServerSideTimestampGenerator() {}
}
