/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.datastax.driver.core.exceptions;

import com.datastax.driver.core.EndPoint;
import java.net.InetAddress;
import java.net.InetSocketAddress;

/**
 * An interface for exceptions that are able to report the address of the coordinator host that was
 * contacted.
 */
public interface CoordinatorException {

  /**
   * The connection information of the coordinator host that was contacted. May be {@code null} if
   * the coordinator is not known.
   */
  EndPoint getEndPoint();

  /**
   * The coordinator host that was contacted; may be {@code null} if the coordinator is not known.
   *
   * @deprecated {@link #getEndPoint()} provides more accurate information if the connection
   *     information consists of more than a socket address. This method is a shortcut for {@code
   *     getEndPoint().resolve().getAddress()}.
   */
  @Deprecated
  InetAddress getHost();

  /**
   * The full address of the coordinator host that was contacted; may be {@code null} if the
   * coordinator is not known.
   *
   * @deprecated {@link #getEndPoint()} provides more accurate information if the connection
   *     information consists of more than a socket address. This method is a shortcut for {@code
   *     getEndPoint().resolve()}.
   */
  @Deprecated
  InetSocketAddress getAddress();
}
